#
# Autogenerated by Thrift Compiler (0.9.0)
#
# DO NOT EDIT UNLESS YOU ARE SURE THAT YOU KNOW WHAT YOU ARE DOING
#
package Thrift::API::HiveClient2::Constants;
$Thrift::API::HiveClient2::Constants::VERSION = '0.026';
{
  $Thrift::API::HiveClient2::Constants::DIST = 'Thrift-API-HiveClient2';
}
require 5.6.0;
use strict;
use warnings;
use Thrift;


use constant PRIMITIVE_TYPES => [
0 => 1,
1 => 1,
2 => 1,
3 => 1,
4 => 1,
5 => 1,
6 => 1,
7 => 1,
8 => 1,
9 => 1,
];

use constant COMPLEX_TYPES => [
10 => 1,
11 => 1,
12 => 1,
13 => 1,
14 => 1,
];

use constant COLLECTION_TYPES => [
10 => 1,
11 => 1,
];

use constant TYPE_NAMES => {
0 => "BOOLEAN",
1 => "TINYINT",
2 => "SMALLINT",
3 => "INT",
4 => "BIGINT",
5 => "FLOAT",
6 => "DOUBLE",
7 => "STRING",
8 => "TIMESTAMP",
9 => "BINARY",
10 => "ARRAY",
11 => "MAP",
12 => "STRUCT",
13 => "UNIONTYPE",
};

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Thrift::API::HiveClient2::Constants

=head1 VERSION

version 0.026

=head1 AUTHOR

David Morel <david.morel@amakuru.net>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2015 by David Morel & Booking.com. Portions are (c) R.Scaffidi, Thrift files are (c) Apache Software Foundation.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut
